#!/bin/bash

# standard P2J server startup script

# defaults
p2j_home=/home/vvt/p2j/branches/4045a
p2j_buildlib="$p2j_home/build/lib"
cpath="../../build/lib/test3909.jar:$p2j_buildlib/p2j.jar:$p2j_buildlib/fwd-hibernate-core-4.1.8-1.jar:$p2j_buildlib/fwdaopltw.jar"

# cpath=""
# for f in ../lib/*.jar
# do
#    cpath=$cpath:$f
# done

debug=0
suspend="n"
hprof=""
prog="java"
srvr="-server"
heap=4768
outlog="../../log/stdout.log"
errlog="../../log/server.log"
cfg="server.xml"
port=""
secure_port=3500
insecure_port=3502
portstep=100
mode=""
statcode="n"
instance=0
batch=""
test=0
usage[0]="\nUsage: $0 [-dyptksw1] [-bprocess] [-zcp] [-hheap] [-llog] [-ccfg] [-iinst]\n"
usage[1]="Where:\n"
usage[2]="d \t= enable JVM debug mode (debugger port will be set as 2080 + instance #)"
usage[3]="y \t= in JVM debug mode enable, suspend the JVM on startup (does not suspend by default)"
usage[4]="p \t= enable JVM hprof (profiling output to gc.log)"
usage[5]="t \t= test mode (displays the command but doesn't execute)"
usage[6]="k \t= kill mode (shuts down the specified/default instance)"
usage[7]="s \t= status mode (displays the status of the specified/default instance)"
usage[8]="w \t= wait mode (does not return until the specified/default instance is STATUS_RUNNING)"
usage[9]="1 \t= enable C1 HotSpot compiler (client compiler for the JVM)"
usage[10]="cp \t= override the classpath which would otherwise be set to $cpath"
usage[11]="heap \t= set JVM max heap size (must be an integer number of MB)"
usage[12]="log \t= log file name (all STDERR is redirected to this file, defaults to ../../log/server.log)"
usage[13]="cfg \t= config file name (P2J bootstrap config file name, defaults to server.xml)"
usage[14]="inst \t= server instance number (0..9, assigns the P2J server port, defaults to 0)"
usage[15]="process \t= launch a program associated with a process account\n";

# process options
while getopts ":dyptksw1z:h:l:c:i:b:" opt; do
   case $opt in
      d  ) debug=1 ;;
      y  ) suspend="y" ;;
      p  ) hprof="-Xrunhprof:heap=dump,doe=y,format=b,file=gc.log" ;;
      t  ) test=1 ;;
      k  ) mode="-k"; statcode="y" ;;
      s  ) mode="-s"; statcode="y" ;;
      w  ) mode="-w -1"; statcode="y" ;;
      b  ) batch="-b $OPTARG" ;;
      1  ) srvr="" ;;
      z  ) cpath=$OPTARG ;;
      h  ) heap=$OPTARG ;;
      l  ) log=$OPTARG ;;
      c  ) cfg=$OPTARG ;; 
      i  ) instance=$OPTARG ;;
      \? ) for i in "${usage[@]}"; do
              echo -e $i
           done
           exit 1 ;;
   esac
done
shift $(($OPTIND - 1))

# final arg prep
cpath="-classpath $cpath"
dport=$((2080 + $instance))

sport=$(($secure_port + $instance))
iport="net:server:insecure_port="$(($insecure_port + $instance))
port="net:connection:secure=true net:server:secure_port=$sport $iport"

if [ $debug -eq 1 ]; then
   dtxt="-Xdebug -Xnoagent -Djava.compiler=NONE -Xrunjdwp:transport=dt_socket,address=$dport,server=y,suspend=$suspend" 
else
   dtxt=""
fi

maxheap="-Xmx"$heap"m"

# run the P2J server
if [ $test -eq 1 ] ; then
   echo $prog $hprof $maxheap $srvr $dtxt $cpath -Djava.system.class.loader=com.goldencode.p2j.classloader.MultiClassLoader com.goldencode.p2j.main.ServerDriver $mode $batch $cfg $port "$@"
else
   eval $prog $hprof $maxheap $srvr $dtxt $cpath -Djava.system.class.loader=com.goldencode.p2j.classloader.MultiClassLoader com.goldencode.p2j.main.ServerDriver $mode $batch $cfg $port "$@" 1>$outlog 2>$errlog
fi

rc=$?

if [ $statcode = "y" ]; then
   case $rc in
      0  ) status="STATUS_RUNNING" ;;
      1  ) status="STATUS_TIMEOUT" ;;
      2  ) status="STATUS_UNKNOWN" ;;
      3  ) status="STATUS_STOPPED" ;;
   esac
   echo "Result =" $status
fi
